@@ -65,8 +65,9 @@ class Wsdl(WsdlBase):
             'groups': [
                 lambda group: group(_("Update the system"),
                                     normal=(
+                                        'cl_update_binhost_stable_opt_set',
                                         'cl_update_binhost_recheck_set',
-                                        'cl_update_binhost_stable_opt_set',),
+                                    ),
                                     expert=(
                                     'cl_update_sync_only_set',
                                     'cl_update_other_set',
